@@ -54,6 +54,7 @@ import org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTabl
 import org.drools.workbench.models.guided.dtable.shared.model.MetadataCol52;
 import org.drools.workbench.models.guided.dtable.shared.model.Pattern52;
 import org.drools.workbench.models.guided.dtable.shared.model.RowNumberCol52;
+import org.drools.workbench.models.guided.dtable.shared.model.RuleNameColumn;
 import org.drools.workbench.models.guided.dtable.shared.validation.HitPolicyValidation;
 import org.drools.workbench.screens.guided.dtable.client.GuidedDecisionTable;
 import org.drools.workbench.screens.guided.dtable.client.editor.clipboard.Clipboard;
@@ -99,12 +100,14 @@ import org.kie.soup.project.datamodel.oracle.DropDownData;
 import org.kie.workbench.common.services.datamodel.model.PackageDataModelOracleBaselinePayload;
 import org.kie.workbench.common.services.shared.rulename.RuleNamesService;
 import org.kie.workbench.common.services.verifier.reporting.client.controller.AnalyzerController;
+import org.kie.workbench.common.services.verifier.reporting.client.panel.AnalysisReportScreen;
 import org.kie.workbench.common.services.verifier.reporting.client.panel.IssueSelectedEvent;
 import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOracle;
 import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOracleFactory;
 import org.kie.workbench.common.widgets.client.resources.i18n.CommonConstants;
 import org.kie.workbench.common.widgets.client.search.common.SearchPerformedEvent;
 import org.kie.workbench.common.widgets.client.search.common.Searchable;
+import org.kie.workbench.common.widgets.decoratedgrid.client.widget.events.SetColumnVisibilityEvent;
 import org.kie.workbench.common.workbench.client.authz.WorkbenchFeatures;
 import org.uberfire.backend.vfs.ObservablePath;
 import org.uberfire.client.callbacks.Callback;
@@ -184,6 +187,7 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
     //This EventBus is local to the screen and should be used for local operations, set data, add rows etc
     private EventBus eventBus = new SimpleEventBus();
     private Set<PortableWorkDefinition> workItemDefinitions;
+    private AnalysisReportScreen analysisReportScreen;
 
     @Inject
     public GuidedDecisionTablePresenter(final User identity,
@@ -294,11 +298,13 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
     @Override
     public void setContent(final ObservablePath path,
                            final PlaceRequest placeRequest,
+                           final AnalysisReportScreen analysisReportScreen,
                            final GuidedDecisionTableEditorContent content,
                            final GuidedDecisionTableModellerView.Presenter parent,
                            final boolean isReadOnly) {
         this.parent = parent;
         this.latestPath = path;
+        this.analysisReportScreen = analysisReportScreen;
 
         initialiseContent(path,
                           placeRequest,
@@ -327,6 +333,7 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
                            final PlaceRequest placeRequest,
                            final GuidedDecisionTableEditorContent content,
                            final boolean isReadOnly) {
+
         final GuidedDecisionTable52 model = content.getModel();
         final PackageDataModelOracleBaselinePayload dataModel = content.getDataModel();
 
@@ -386,6 +393,7 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
                 final Range rows = super.selectCell(rowIndex,
                                                     columnIndex);
                 decisionTableSelectionsChangedEvent.fire(new DecisionTableSelectionsChangedEvent(GuidedDecisionTablePresenter.this));
+                lockManager.acquireLock();
                 return rows;
             }
 
@@ -399,6 +407,7 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
                                                      width,
                                                      height);
                 decisionTableSelectionsChangedEvent.fire(new DecisionTableSelectionsChangedEvent(GuidedDecisionTablePresenter.this));
+                lockManager.acquireLock();
                 return rows;
             }
 
@@ -511,7 +520,8 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
 
     //Setup the Validation & Verification analyzer
     void initialiseValidationAndVerification() {
-        this.analyzerController = decisionTableAnalyzerProvider.newAnalyzer(placeRequest,
+        this.analyzerController = decisionTableAnalyzerProvider.newAnalyzer(analysisReportScreen,
+                                                                            placeRequest,
                                                                             oracle,
                                                                             model,
                                                                             eventBus);
@@ -601,9 +611,10 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
 
     @Override
     public void initialiseAnalysis() {
-        if (analyzerController != null) {
-            analyzerController.initialiseAnalysis();
+        if (analyzerController == null) {
+            initialiseValidationAndVerification();
         }
+        analyzerController.initialiseAnalysis();
     }
 
     @Override
@@ -933,6 +944,7 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
         }
         try {
             synchronizer.appendRow();
+            lockManager.acquireLock();
 
             refreshView();
 
@@ -994,6 +1006,24 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
         callback.execute();
     }
 
+
+    @Override
+    public void onSort(final GridColumn gridColumn) {
+        final List<Integer> sort = uiModel.sort(gridColumn);
+        refreshView();
+        analyzerController.sort(sort);
+    }
+
+    @Override
+    public void setShowRuleName(final boolean show) {
+        model.getRuleNameColumn().setHideColumn(!show);
+        eventBus.fireEvent(new SetColumnVisibilityEvent(1, show));
+        final int iModelColumn = model.getExpandedColumns().indexOf(model.getRuleNameColumn());
+        uiModel.getColumns().get(iModelColumn).setVisible(show);
+
+        refreshView();
+    }
+
     @Override
     public void updateColumn(final AttributeCol52 originalColumn,
                              final AttributeCol52 editedColumn) throws VetoException {
@@ -1261,7 +1291,7 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
         for (int selectedColumnIndex : selectedColumnIndexes) {
             final int columnIndex = findUiColumnIndex(selectedColumnIndex);
             final BaseColumn column = model.getExpandedColumns().get(columnIndex);
-            if (!(column instanceof RowNumberCol52 || column instanceof DescriptionCol52)) {
+            if (!(column instanceof RowNumberCol52 || column instanceof DescriptionCol52 || column instanceof RuleNameColumn)) {
                 columnsToDelete.add(column);
             }
         }
@@ -1455,13 +1485,13 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
     }
 
     @Override
-    public boolean hasEditableColumns() {
-        return getAccess().hasEditableColumns();
+    public void setReadOnly(final boolean isReadOnly) {
+        this.access.setReadOnly(isReadOnly);
     }
 
     @Override
-    public void setReadOnly(final boolean isReadOnly) {
-        this.access.setReadOnly(isReadOnly);
+    public boolean hasEditableColumns() {
+        return getAccess().hasEditableColumns();
     }
 
     @Override
@@ -1512,6 +1542,10 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
             return isReadOnly;
         }
 
+        public void setReadOnly(final boolean isReadOnly) {
+            this.isReadOnly = isReadOnly;
+        }
+
         public boolean hasEditableColumns() {
             return hasEditableColumns;
         }
@@ -1520,10 +1554,6 @@ public class GuidedDecisionTablePresenter implements GuidedDecisionTableView.Pre
             this.hasEditableColumns = hasEditableColumns;
         }
 
-        public void setReadOnly(final boolean isReadOnly) {
-            this.isReadOnly = isReadOnly;
-        }
-
         public boolean isEditable() {
             return !(lock == OTHER_USER || isReadOnly);
         }
