@@ -39,6 +39,7 @@ import org.guvnor.common.services.shared.metadata.model.Overview;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.kie.soup.project.datamodel.imports.Imports;
+import org.kie.workbench.common.services.verifier.reporting.client.panel.AnalysisReportScreen;
 import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOracle;
 import org.kie.workbench.common.widgets.client.search.common.SearchPerformedEvent;
 import org.kie.workbench.common.workbench.client.docks.AuthoringWorkbenchDocks;
@@ -62,6 +63,7 @@ import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertNotNull;
 import static org.junit.Assert.assertTrue;
+import static org.mockito.Matchers.anySet;
 import static org.mockito.Matchers.same;
 import static org.mockito.Mockito.any;
 import static org.mockito.Mockito.doReturn;
@@ -76,13 +78,11 @@ import static org.mockito.Mockito.when;
 @RunWith(GwtMockitoTestRunner.class)
 public class GuidedDecisionTableEditorPresenterTest extends BaseGuidedDecisionTablePresenterTest<GuidedDecisionTableEditorPresenter> {
 
-    private GuidedDTableResourceType resourceType = new GuidedDTableResourceType(new Decision());
-
-    @Mock
-    private SaveAndRenameCommandBuilder<GuidedDecisionTable52, Metadata> saveAndRenameCommandBuilder;
-
     @Mock
     protected AuthoringWorkbenchDocks docks;
+    private GuidedDTableResourceType resourceType = new GuidedDTableResourceType(new Decision());
+    @Mock
+    private SaveAndRenameCommandBuilder<GuidedDecisionTable52, Metadata> saveAndRenameCommandBuilder;
 
     @Mock
     private EventSourceMock<SearchPerformedEvent> searchPerformedEvent;
@@ -96,6 +96,8 @@ public class GuidedDecisionTableEditorPresenterTest extends BaseGuidedDecisionTa
                                                       mock(PerspectiveManager.class),
                                                       notification,
                                                       decisionTableSelectedEvent,
+                                                      mock(GuidedDecisionTableDocksHandler.class),
+                                                      mock(AnalysisReportScreen.class),
                                                       validationPopup,
                                                       resourceType,
                                                       editMenuBuilder,
@@ -437,8 +439,8 @@ public class GuidedDecisionTableEditorPresenterTest extends BaseGuidedDecisionTa
 
         presenter.onConvert();
 
-        verify(view).showConversionSuccess();
-        verify(view, never()).showConversionMessage(any());
+        verify(view).showConversionSuccess(anySet());
+        verify(view, never()).showConversionErrorMessage(any());
     }
 
     @Test
@@ -447,7 +449,7 @@ public class GuidedDecisionTableEditorPresenterTest extends BaseGuidedDecisionTa
 
         presenter.onConvert();
 
-        verify(view, never()).showConversionSuccess();
-        verify(view).showConversionMessage("failed");
+        verify(view, never()).showConversionSuccess(anySet());
+        verify(view).showConversionErrorMessage("failed");
     }
 }
